Skip to main contentCrate bevy_auto_plugin_proc_macros
Source - auto_add_message
- Automatically registers an message to be added to the app.
- auto_add_observer
- Automatically adds a global observer
- auto_add_plugin
- Automatically inserts a plugin as a sub-plugin into the app.
- auto_add_system
- Automatically registers a system to be added to the app.
- auto_bind_plugin
- Automatically sets
plugin = _ (and optionally after_build) for all #[auto_*(..)] macros below it - auto_component
- Automatically registers a component to be added to the app.
- auto_configure_system_set
- Automatically configures a SystemSet for the app.
- auto_event
- Automatically registers an event to be added to the app.
- auto_init_resource
- Automatically registers a resource to be initialized in the app.
- auto_init_state
- Automatically initializes a state in the app.
- auto_init_sub_state
- Automatically initializes a sub state in the app.
- auto_insert_resource
- Automatically inserts a resource with a specific value into the app.
- auto_message
- Automatically registers an event to be added to the app.
- auto_name
- Automatically adds a Name component to entities with this component.
- auto_observer
- Automatically adds a global observer
- auto_plugin
- Attribute to mark the build function for the plugin, or impl Plugin trait build method for injection
- auto_plugin_build_hook
- Registers a build hook to run custom logic for a type when a plugin builds.
- auto_register_state_type
- Automatically registers
State<T> and NextState<T> types with the app. - auto_register_type
- Automatically registers a type with the app’s type registry.
- auto_resource
- Automatically registers a resource to be added to the app.
- auto_run_on_build
- Automatically runs the
fn(&mut App) -> () when the Plugin::build is called. - auto_states
- Automatically initializes a state in the app.
- auto_sub_states
- Automatically initializes a sub-state in the app.
- auto_system
- Automatically registers a system to be added to the app.
- AutoPlugin
- A derive macro that implements Plugin for a struct and collects registered components,
events, resources, and systems.